Maven Pro is a sans-serif typeface with unique curvature and flowing rhythm. Its forms make it very distinguishable and legible when in context. It blends styles of many great typefaces and is suitable for any design medium. Maven Pro’s modern design is great for the web and fits in any environment.

Updated in January 2019 with a Variable Font "Weight" axis.

The Maven Pro project was initiated by Joe Price, a type designer based in the USA. To contribute, see github.com/googlefonts/mavenproFont